==> nan_common_utils-0.0.14.tar.gz: lib/nan_widget_util.dart <==

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:nan_common_utils/nan_util.dart';

class NanWidgetUtil{

  static Widget commonTextField(TextEditingController textEditingController,{int maxLines=1,bool isHiddenLine = false,bool isRequired=false,double rightIconWidth=30,int maxLength,double height,bool enabled=true,String leftTitle,String rightImg='location',String hintText="请输入",int flex=2,TextInputAction textInputAction=TextInputAction.done,List<TextInputFormatter> inputFormatters,TextInputType keyboardType,GestureTapCallback locationnTap,Function onChangeFun}){  
    return Column(
      children: [
        Container(
          color: Colors.white,
          height: height,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.only(left: 13,right: 20),
                child: Row(
                  children: [
                    Offstage(
                      offstage: !isRequired,
                      child: Text("*",style: TextStyle(color: Colors.redAccent,fontSize: 18,fontWeight: FontWeight.bold),),
                    ),
                    Text(leftTitle,style: TextStyle(color: Colors.black,fontSize: 14),)
                  ],
                ),
              ),
              Expanded(
                flex: flex,
                child: Container(
                  child: TextField(
                    enabled: enabled,
                    maxLines: maxLines,//null,
                    maxLength: maxLength,//1024,
                    controller: textEditingController,
                    textAlign: TextAlign.right,
                    textInputAction: textInputAction,
                    inputFormatters: inputFormatters,
                    keyboardType: keyboardType,//TextInputType.number,
                    decoration: InputDecoration(
                      contentPadding: const EdgeInsets.all(10.0),
                      hintText: hintText,
                      hintStyle: TextStyle(color: Color.fromRGBO(204,204,204, 1)),
                      border: OutlineInputBorder(
                        borderSide: BorderSide.none
                      ),
                      filled: true,
                      fillColor: Colors.white//Colous.LoginTextBColor,
                    ),
                    onChanged: (value) {
                      // Toast.show(value, context,gravity: Toast.CENTER);
                      if (onChangeFun != null) {
                        onChangeFun(value);
                      }
                    },
                  ),
                ),
              ),
              Offstage(
                offstage: locationnTap == null,
                child: Padding(
                  padding: EdgeInsets.only(right: 10),
                  child: loadAssetImage(rightImg,width: rightIconWidth,height: rightIconWidth,onTap: locationnTap),
                ),
              )
            ],
          ),
        ),
        Offstage(
          offstage: isHiddenLine,
          child: Divider(height: 1,),
        )
      ],
    );           
  }

  static Widget reportRecordDetailWidget(leftTitle,{double mHeight=50,bool isRequired=false,double rightIconMargin=0,Color lineColor,bool isHiddenLine=false,double lineHeight=1,double titleMarginLeft=13,Color leftTitleColor,Color bgColor=Colors.white,double fSize=14,String rightTitle,String rightIcon="scan",TextAlign textAlign =TextAlign.right,bool isHiddenRightIcon=true,GestureTapCallback rightIconOnTap,Color rightTitleColor,FontWeight fontWeight=FontWeight.normal}){
    Color leftTitleColors = (leftTitleColor == null?Color.fromRGBO(102,102,102, 1):leftTitleColor);
    return Column(
      children: <Widget>[
        Container(
          color: bgColor,
          // padding: EdgeInsets.all(5),
          constraints: BoxConstraints(
            minHeight: mHeight
          ),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Expanded(
                child: Padding(
                    padding: EdgeInsets.only(left: 13,right: 20),
                    child: Row(
                      children: [
                        Offstage(
                          offstage: !isRequired,
                          child: Text("*",style: TextStyle(color: Colors.redAccent,fontSize: 18,fontWeight: FontWeight.bold),),
                        ),
                        Text(leftTitle,style: TextStyle(fontSize: fSize,color: leftTitleColors,fontWeight: fontWeight))
                      ],
                    ),
                  ),
              ),
              rightIconOnTap == null?
              Offstage(
                offstage:  NanUtil.isStrEmpty(rightTitle) ? true:false,
                child: Container(
                  // color: color,
                  // width: kScreenWidth-100-20-20-20,
                  constraints: BoxConstraints(
                    maxWidth: NanUtil.kScreenWidth-100-20
                  ),
                  margin: EdgeInsets.only(right: 10),
                  child: Text(NanUtil.isEmpty(rightTitle),style: TextStyle(color: rightTitleColor),textAlign: textAlign,),
                ),
              )
              :Padding(
                padding: EdgeInsets.only(right: rightIconMargin),
                child: NanWidgetUtil.loadAssetImage(rightIcon,width: 30,height: 30,onTap: rightIconOnTap),
              ),
            ],
          ),
        ),
        Offstage(
          offstage: isHiddenLine,
          child: Divider(height: lineHeight,color: lineColor,),
        )
      ],
    );
  }

  //加载本地资源图片
  static Widget loadAssetImage(String name,{double width,double height,BoxFit fit,String format:'png',GestureTapCallback onTap}){
    return InkWell(
      child: Image.asset(
        NanUtil.getImagePath(name,format: format),
        height: height,
        width: width,
        fit: fit,
      ),
      onTap: onTap,
    );
  }

  // static void showUploadDialog(BuildContext context,{String upload,Color loadingColor,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback onTap}){
  //   showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
  //     return NanBaseDialog(
  //       Column(
  //         children: <Widget>[
  //           SizedBox(height: 20,),
  //           NanWidgetUtil.loadingWidget(loadingColor: loadingColor),
  //           InkWell(
  //             child: Padding(
  //               padding: EdgeInsets.only(top: 20),
  //               child: Text(tipMsg),
  //             ),
  //             onTap: onTap,
  //           )
  //         ],
  //       ), 
  //       150, 
  //       NanUtil.kScreenWidth - 46*2, 
  //       radius
  //     );
  //   },);
  // }

  static Widget loadingWidget({Color loadingColor}){
    loadingColor = loadingColor==null?Color.fromRGBO(0,189,144, 1):loadingColor;
    return SpinKitDoubleBounce(
      color: loadingColor,
    );
  }

  static AppBar commonAppBar({String title='标题',TextStyle titleTextStyle,bool centerTitle=true, Color bgColor=Colors.white,double elevation,List<Widget> actions,Widget leading,PreferredSizeWidget bottom,Gradient mainGradient}){
    return AppBar(
      title: Text(title,style: titleTextStyle,),
      centerTitle: centerTitle,
      backgroundColor: bgColor,
      elevation: elevation,
      actions: actions,
      leading: leading,
      bottom: bottom,
      flexibleSpace: Container(
        decoration: BoxDecoration(
          gradient: mainGradient
        ),
      ),
    );
  }

  static Widget cachedNetworkImageWidget(BuildContext context,int index,List imageFiles,String filePath,{String placeholderImg="placeholderImg",GestureTapCallback onTap}){
    return GestureDetector(
      onTap: onTap,
      child: CachedNetworkImage(
        imageUrl: filePath,
        placeholder: (context,url) => NanWidgetUtil.loadAssetImage(placeholderImg),
        errorWidget: (context,url,error) => NanWidgetUtil.loadAssetImage(placeholderImg),
      ),
    );
  }



}

==> nan_common_utils-0.0.15.tar.gz: lib/nan_widget_util.dart <==

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:nan_common_utils/nan_util.dart';

class NanWidgetUtil{

  static Widget commonTextField(TextEditingController textEditingController,{int maxLines=1,bool isHiddenLine = false,bool isRequired=false,double rightIconWidth=30,int maxLength,double height,bool enabled=true,String leftTitle,String rightImg='location',String hintText="请输入",int flex=2,TextInputAction textInputAction=TextInputAction.done,List<TextInputFormatter> inputFormatters,TextInputType keyboardType,GestureTapCallback locationnTap,Function onChangeFun}){  
    return Column(
      children: [
        Container(
          color: Colors.white,
          height: height,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.only(left: 13,right: 20),
                child: Row(
                  children: [
                    Offstage(
                      offstage: !isRequired,
                      child: Text("*",style: TextStyle(color: Colors.redAccent,fontSize: 18,fontWeight: FontWeight.bold),),
                    ),
                    Text(leftTitle,style: TextStyle(color: Colors.black,fontSize: 14),)
                  ],
                ),
              ),
              Expanded(
                flex: flex,
                child: Container(
                  child: TextField(
                    enabled: enabled,
                    maxLines: maxLines,//null,
                    maxLength: maxLength,//1024,
                    controller: textEditingController,
                    textAlign: TextAlign.right,
                    textInputAction: textInputAction,
                    inputFormatters: inputFormatters,
                    keyboardType: keyboardType,//TextInputType.number,
                    decoration: InputDecoration(
                      contentPadding: const EdgeInsets.all(10.0),
                      hintText: hintText,
                      hintStyle: TextStyle(color: Color.fromRGBO(204,204,204, 1)),
                      border: OutlineInputBorder(
                        borderSide: BorderSide.none
                      ),
                      filled: true,
                      fillColor: Colors.white//Colous.LoginTextBColor,
                    ),
                    onChanged: (value) {
                      // Toast.show(value, context,gravity: Toast.CENTER);
                      if (onChangeFun != null) {
                        onChangeFun(value);
                      }
                    },
                  ),
                ),
              ),
              Offstage(
                offstage: locationnTap == null,
                child: Padding(
                  padding: EdgeInsets.only(right: 10),
                  child: loadAssetImage(rightImg,width: rightIconWidth,height: rightIconWidth,onTap: locationnTap),
                ),
              )
            ],
          ),
        ),
        Offstage(
          offstage: isHiddenLine,
          child: Divider(height: 1,),
        )
      ],
    );           
  }

  static Widget reportRecordDetailWidget(leftTitle,{double mHeight=50,bool isRequired=false,double rightIconMargin=0,
                                        String lineType=NanLineType.divider,Color lineColor,bool isHiddenLine=false,double lHeight=1,
                                        double lWidth=0,double titleMarginLeft=13,Color leftTitleColor,Color bgColor=Colors.white,
                                        double fSize=14,String rightTitle,String rightIcon="scan",TextAlign textAlign =TextAlign.right,
                                        bool isHiddenRightIcon=true,GestureTapCallback rightIconOnTap,Color rightTitleColor,
                                        FontWeight fontWeight=FontWeight.normal,Color requiredColor=Colors.redAccent}){
    Color leftTitleColors = (leftTitleColor == null?Color.fromRGBO(102,102,102, 1):leftTitleColor);
    return Column(
    children: <Widget>[
      Container(
        color: bgColor,
        // padding: EdgeInsets.all(5),
        constraints: BoxConstraints(
          minHeight: mHeight
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Expanded(
              child: Padding(
                  padding: EdgeInsets.only(left: 13,right: 20),
                  child: Row(
                    children: [
                      Offstage(
                        offstage: !isRequired,
                        child: Text("*",style: TextStyle(color: requiredColor,fontSize: 18,fontWeight: FontWeight.bold),),
                      ),
                      Text(leftTitle,style: TextStyle(fontSize: fSize,color: leftTitleColors,fontWeight: fontWeight))
                    ],
                  ),
                ),
            ),
            rightIconOnTap == null?
            Offstage(
              offstage:  NanUtil.isStrEmpty(rightTitle) ? true:false,
              child: Container(
                // color: color,
                // width: kScreenWidth-100-20-20-20,
                constraints: BoxConstraints(
                  maxWidth: NanUtil.kScreenWidth-100-20
                ),
                margin: EdgeInsets.only(right: 10),
                child: Text(NanUtil.isEmpty(rightTitle),style: TextStyle(color: rightTitleColor),textAlign: textAlign,),
              ),
            )
            :Padding(
              padding: EdgeInsets.only(right: rightIconMargin),
              child: NanWidgetUtil.loadAssetImage(rightIcon,width: 30,height: 30,onTap: rightIconOnTap),
            ),
          ],
        ),
      ),
      Offstage(
        offstage: isHiddenLine,
        child: lineType == NanLineType.divider ? Divider(height: lHeight,color: lineColor,):lineHeight(height: lHeight,lineColor: lineColor,width: lWidth),
      )
    ],
  );
  }

  //加载本地资源图片
  static Widget loadAssetImage(String name,{double width,double height,BoxFit fit,String format:'png',GestureTapCallback onTap}){
    return InkWell(
      child: Image.asset(
        NanUtil.getImagePath(name,format: format),
        height: height,
        width: width,
        fit: fit,
      ),
      onTap: onTap,
    );
  }

  // static void showUploadDialog(BuildContext context,{String upload,Color loadingColor,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback onTap}){
  //   showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
  //     return NanBaseDialog(
  //       Column(
  //         children: <Widget>[
  //           SizedBox(height: 20,),
  //           NanWidgetUtil.loadingWidget(loadingColor: loadingColor),
  //           InkWell(
  //             child: Padding(
  //               padding: EdgeInsets.only(top: 20),
  //               child: Text(tipMsg),
  //             ),
  //             onTap: onTap,
  //           )
  //         ],
  //       ), 
  //       150, 
  //       NanUtil.kScreenWidth - 46*2, 
  //       radius
  //     );
  //   },);
  // }

  static Widget loadingWidget({Color loadingColor}){
    loadingColor = loadingColor==null?Color.fromRGBO(0,189,144, 1):loadingColor;
    return SpinKitDoubleBounce(
      color: loadingColor,
    );
  }

  static AppBar commonAppBar({String title='标题',TextStyle titleTextStyle,bool centerTitle=true, Color bgColor=Colors.white,double elevation,List<Widget> actions,Widget leading,PreferredSizeWidget bottom,Gradient mainGradient}){
    return AppBar(
      title: Text(title,style: titleTextStyle,),
      centerTitle: centerTitle,
      backgroundColor: bgColor,
      elevation: elevation,
      actions: actions,
      leading: leading,
      bottom: bottom,
      flexibleSpace: Container(
        decoration: BoxDecoration(
          gradient: mainGradient
        ),
      ),
    );
  }

  static Widget cachedNetworkImageWidget(BuildContext context,int index,List imageFiles,String filePath,{String placeholderImg="placeholderImg",GestureTapCallback onTap}){
    return GestureDetector(
      onTap: onTap,
      child: CachedNetworkImage(
        imageUrl: filePath,
        placeholder: (context,url) => NanWidgetUtil.loadAssetImage(placeholderImg),
        errorWidget: (context,url,error) => NanWidgetUtil.loadAssetImage(placeholderImg),
      ),
    );
  }

  static Widget lineHeight({double height=1,double width=0,Color lineColor}){
    Color lColor = lineColor==null ? Color.fromRGBO(229,229,229, 1):lineColor;
    return Container(
      color: lColor,
      height: height,
      width: width==0?NanUtil.kScreenWidth-16*2:width,
    );
  }



}
